@@ -38,7 +38,7 @@
 /**
  * SECTION:giomodule
  * @short_description: Loadable GIO Modules
- * @include: gio.h
+ * @include: gio/gio.h
  *
  * Provides an interface and default functions for loading and unloading 
  * modules. This is used internally to make GIO extensible, but can also
@@ -230,9 +230,9 @@ is_valid_module_name (const gchar *basename)
 /**
  * g_io_modules_load_all_in_directory:
  * @dirname: pathname for a directory containing modules to load.
- * 
- * Loads all the modules in the the specified directory. 
- * 
+ *
+ * Loads all the modules in the specified directory.
+ *
  * Returns: a list of #GIOModules loaded from the directory,
  *      All the modules are loaded into memory, if you want to
  *      unload them (enabling on-demand loading) you must call
@@ -285,17 +285,22 @@ g_io_modules_load_all_in_directory (const char *dirname)
 
 G_LOCK_DEFINE_STATIC (loaded_dirs);
 
+extern GType _g_fen_directory_monitor_get_type (void);
+extern GType _g_fen_file_monitor_get_type (void);
 extern GType _g_inotify_directory_monitor_get_type (void);
 extern GType _g_inotify_file_monitor_get_type (void);
 extern GType _g_unix_volume_monitor_get_type (void);
 extern GType _g_local_vfs_get_type (void);
 
+extern GType g_win32_directory_monitor_get_type (void);
+
 void
 _g_io_modules_ensure_loaded (void)
 {
   GList *modules, *l;
   static gboolean loaded_dirs = FALSE;
   GIOExtensionPoint *ep;
+  const char *module_path;
 
   G_LOCK (loaded_dirs);
 
@@ -325,11 +330,35 @@ _g_io_modules_ensure_loaded (void)
       
       modules = g_io_modules_load_all_in_directory (GIO_MODULE_DIR);
 
+      module_path = g_getenv ("GIO_EXTRA_MODULES");
+
+      if (module_path)
+        {
+          int i = 0;
+          gchar **paths;
+          paths = g_strsplit (module_path, ":", 0);
+    
+          while (paths[i] != NULL)
+            { 
+              modules = g_list_prepend (modules, g_io_modules_load_all_in_directory (paths[i]));
+              i++;
+            }
+
+          g_strfreev (paths);
+        }
+
       /* Initialize types from built-in "modules" */
 #if defined(HAVE_SYS_INOTIFY_H) || defined(HAVE_LINUX_INOTIFY_H)
       _g_inotify_directory_monitor_get_type ();
       _g_inotify_file_monitor_get_type ();
 #endif
+#if defined(HAVE_FEN)
+      _g_fen_directory_monitor_get_type ();
+      _g_fen_file_monitor_get_type ();
+#endif
+#ifdef G_OS_WIN32
+      g_win32_directory_monitor_get_type ();
+#endif
 #ifdef G_OS_UNIX
       _g_unix_volume_monitor_get_type ();
 #endif
