@@ -37,14 +37,14 @@
 /**
  * SECTION:gmount
  * @short_description: Mount management
- * @include: gio.h
+ * @include: gio/gio.h
  * @see also: GVolume, GUnixMount
  *
  * The #GMount interface represents user-visible mounts. Note, when 
  * porting from GnomeVFS, #GMount is the moral equivalent of #GnomeVFSVolume.
  *
  * #GMount is a "mounted" filesystem that you can access. Mounted is in
- * quotes because its not the same as a unix mount, it might be a gvfs
+ * quotes because it's not the same as a unix mount, it might be a gvfs
  * mount, but you can still access the files on it if you use GIO. Might or
  * might not be related to a volume object.
  * 
@@ -313,7 +313,7 @@ g_mount_can_eject (GMount *mount)
  * @mount: a #GMount.
  * @flags: flags affecting the operation
  * @cancellable: optional #GCancellable object, %NULL to ignore.
- * @callback: a #GAsyncReadyCallback.
+ * @callback: a #GAsyncReadyCallback, or %NULL.
  * @user_data: user data passed to @callback.
  * 
  * Unmounts a mount. This is an asynchronous operation, and is 
@@ -338,8 +338,11 @@ g_mount_unmount (GMount *mount,
       g_simple_async_report_error_in_idle (G_OBJECT (mount),
 					   callback, user_data,
 					   G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+					   /* Translators: This is an error
+					    * message for mount objects that
+					    * don't implement unmount. */
 					   _("mount doesn't implement unmount"));
-      
+
       return;
     }
   
@@ -353,7 +356,7 @@ g_mount_unmount (GMount *mount,
  * @error: a #GError location to store the error occuring, or %NULL to 
  * ignore.
  * 
- * Finishes unmounting a mount. If any errors occured during the operation, 
+ * Finishes unmounting a mount. If any errors occurred during the operation, 
  * @error will be set to contain the errors and %FALSE will be returned.
  * 
  * Returns: %TRUE if the mount was successfully unmounted. %FALSE otherwise.
@@ -385,7 +388,7 @@ g_mount_unmount_finish (GMount       *mount,
  * @mount: a #GMount.
  * @flags: flags affecting the unmount if required for eject
  * @cancellable: optional #GCancellable object, %NULL to ignore.
- * @callback: a #GAsyncReadyCallback.
+ * @callback: a #GAsyncReadyCallback, or %NULL.
  * @user_data: user data passed to @callback.
  * 
  * Ejects a mount. This is an asynchronous operation, and is 
@@ -410,6 +413,9 @@ g_mount_eject (GMount *mount,
       g_simple_async_report_error_in_idle (G_OBJECT (mount),
 					   callback, user_data,
 					   G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+					   /* Translators: This is an error
+					    * message for mount objects that
+					    * don't implement eject. */
 					   _("mount doesn't implement eject"));
       
       return;
@@ -425,7 +431,7 @@ g_mount_eject (GMount *mount,
  * @error: a #GError location to store the error occuring, or %NULL to 
  * ignore.
  * 
- * Finishes ejecting a mount. If any errors occured during the operation, 
+ * Finishes ejecting a mount. If any errors occurred during the operation, 
  * @error will be set to contain the errors and %FALSE will be returned.
  * 
  * Returns: %TRUE if the mount was successfully ejected. %FALSE otherwise.
@@ -454,13 +460,14 @@ g_mount_eject_finish (GMount       *mount,
 /**
  * g_mount_remount:
  * @mount: a #GMount.
+ * @flags: flags affecting the operation
  * @mount_operation: a #GMountOperation or %NULL to avoid user interaction.
  * @cancellable: optional #GCancellable object, %NULL to ignore.
- * @callback: a #GAsyncReadyCallback.
+ * @callback: a #GAsyncReadyCallback, or %NULL.
  * @user_data: user data passed to @callback.
  * 
  * Remounts a mount. This is an asynchronous operation, and is 
- * finished by calling g_mount_unmount_finish() with the @mount 
+ * finished by calling g_mount_remount_finish() with the @mount 
  * and #GAsyncResults data returned in the @callback.
  *
  * Remounting is useful when some setting affecting the operation
@@ -471,6 +478,7 @@ g_mount_eject_finish (GMount       *mount,
  **/
 void
 g_mount_remount (GMount *mount,
+                 GMountMountFlags flags,
                  GMountOperation *mount_operation,
                  GCancellable *cancellable,
                  GAsyncReadyCallback callback,
@@ -483,16 +491,19 @@ g_mount_remount (GMount *mount,
   iface = G_MOUNT_GET_IFACE (mount);
 
   if (iface->remount == NULL)
-    {
-      g_simple_async_report_error_in_idle (G_OBJECT (mount),
+    { 
+     g_simple_async_report_error_in_idle (G_OBJECT (mount),
 					   callback, user_data,
 					   G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+					   /* Translators: This is an error
+					    * message for mount objects that
+					    * don't implement remount. */
 					   _("mount doesn't implement remount"));
       
       return;
     }
   
-  (* iface->remount) (mount, mount_operation, cancellable, callback, user_data);
+  (* iface->remount) (mount, flags, mount_operation, cancellable, callback, user_data);
 }
 
 /**
@@ -502,7 +513,7 @@ g_mount_remount (GMount *mount,
  * @error: a #GError location to store the error occuring, or %NULL to 
  * ignore.
  * 
- * Finishes remounting a mount. If any errors occured during the operation, 
+ * Finishes remounting a mount. If any errors occurred during the operation, 
  * @error will be set to contain the errors and %FALSE will be returned.
  * 
  * Returns: %TRUE if the mount was successfully remounted. %FALSE otherwise.
